# For data carpenting and gardening

# Importing dependencies

import os 
import dask.dataframe as dd
import pickle as pkl

# mypath = '/home/user/rundir/workdir/result'
# filepattern = '.dat'
# myfilepaths= survey(mypath, filepattern)

def survey(path,filepattern):
# Survey all files under path directory
    filepaths_ALL = []
    #Path = "/home/user/rundir/workdir"
    for (dirpath, dirnames, filenames) in os.walk(path):
        for filename in filenames:
            if filepattern in filename:
                filepath = "{}/{}".format(dirpath,filename)
                filepaths_ALL.append(filepath)
    print("A total of ",len(filepaths_ALL),filepattern," files are detected")
    return filepaths_ALL



import setuptools

with open("README.md", "r", encoding="utf-8") as fh:
    long_description = fh.read()

setuptools.setup(
    name="ArtisanKit", # Replace with your own username
    version="0.0.3",
    author="dominikusbrian",
    author_email="dominikusbrian@nyu.com",
    description="A Productivity Toolkit for Craftsman/woman Doing Research in Computational Chemistry, Machine Learning, and Beyond.",
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/xiangsunlab/ArtisanKit",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: GNU Lesser General Public License v3 (LGPLv3)",
        "Operating System :: OS Independent",
    ],
    python_requires='>=3.8',
)

